# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import onelogin
from onelogin.models.client_app_full import ClientAppFull  # noqa: E501
from onelogin.rest import ApiException

class TestClientAppFull(unittest.TestCase):
    """ClientAppFull unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ClientAppFull
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ClientAppFull`
        """
        model = onelogin.models.client_app_full.ClientAppFull()  # noqa: E501
        if include_optional :
            return ClientAppFull(
                scopes = [
                    onelogin.models.scope.scope(
                        id = 25, 
                        value = 'read:contacts', 
                        description = 'Read some contacts', )
                    ], 
                app_id = 1026152, 
                name = 'An oidc app', 
                api_auth_id = 1033034
            )
        else :
            return ClientAppFull(
        )
        """

    def testClientAppFull(self):
        """Test ClientAppFull"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
