# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import onelogin
from onelogin.models.get_role_by_id200_response_data_inner import GetRoleById200ResponseDataInner  # noqa: E501
from onelogin.rest import ApiException

class TestGetRoleById200ResponseDataInner(unittest.TestCase):
    """GetRoleById200ResponseDataInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test GetRoleById200ResponseDataInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetRoleById200ResponseDataInner`
        """
        model = onelogin.models.get_role_by_id200_response_data_inner.GetRoleById200ResponseDataInner()  # noqa: E501
        if include_optional :
            return GetRoleById200ResponseDataInner(
                id = 123456, 
                name = 'Employee'
            )
        else :
            return GetRoleById200ResponseDataInner(
        )
        """

    def testGetRoleById200ResponseDataInner(self):
        """Test GetRoleById200ResponseDataInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
