# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictInt
from onelogin.models.get_risk_scores200_response_scores import GetRiskScores200ResponseScores

class GetRiskScores200Response(BaseModel):
    """
    GetRiskScores200Response
    """
    scores: Optional[GetRiskScores200ResponseScores] = None
    total: Optional[StrictInt] = None
    __properties = ["scores", "total"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> GetRiskScores200Response:
        """Create an instance of GetRiskScores200Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of scores
        if self.scores:
            _dict['scores'] = self.scores.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> GetRiskScores200Response:
        """Create an instance of GetRiskScores200Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return GetRiskScores200Response.parse_obj(obj)

        _obj = GetRiskScores200Response.parse_obj({
            "scores": GetRiskScores200ResponseScores.from_dict(obj.get("scores")) if obj.get("scores") is not None else None,
            "total": obj.get("total")
        })
        return _obj

